<?php

/**
 * This file is part of Laravel HTMLMin by Graham Campbell.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

namespace GrahamCampbell\HTMLMin\Compilers;

use Illuminate\Filesystem\Filesystem;
use Illuminate\View\Compilers\BladeCompiler;
use GrahamCampbell\HTMLMin\Classes\HTMLMin;

/**
 * This is the htmlmin compiler class.
 *
 * @package    Laravel-HTMLMin
 * @author     Graham Campbell
 * @copyright  Copyright 2013-2014 Graham Campbell
 * @license    https://github.com/GrahamCampbell/Laravel-HTMLMin/blob/master/LICENSE.md
 * @link       https://github.com/GrahamCampbell/Laravel-HTMLMin
 */
class HTMLMinCompiler extends BladeCompiler
{
    /**
     * The htmlmin instance.
     *
     * @var \GrahamCampbell\HTMLMin\Classes\HTMLMin
     */
    protected $htmlmin;

    /**
     * Create a new instance.
     *
     * @param  \GrahamCampbell\HTMLMin\Classes\HTMLMin  $htmlmin
     * @param  \Illuminate\Filesystem\Filesystem  $files
     * @param  string  $cachePath
     * @return void
     */
    public function __construct(HTMLMin $htmlmin, Filesystem $files, $cachePath)
    {
        parent::__construct($files, $cachePath);
        $this->htmlmin = $htmlmin;
        $this->compilers[] = 'Minify';
    }

    /**
    * Minifies the HTML output before saving it.
    *
    * @param  string  $value
    * @return string
    */
    public function compileMinify($value)
    {
        return $this->htmlmin->blade($value);
    }

    /**
     * Return the compilers.
     *
     * @return array
     */
    public function getCompilers()
    {
        return $this->compilers;
    }

    /**
     * Return the htmlmin instance.
     *
     * @return \GrahamCampbell\HTMLMin\Classes\HTMLMin
     */
    public function getHTMLMin()
    {
        return $this->htmlmin;
    }
}
